<?php
/**
 * Header file for the Videocast WordPress theme.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Videocast
 * @since 1.0.0
 */
?>
<!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

    <?php
if( function_exists('wp_body_open') ){
    wp_body_open();
} ?>

    <div class="theme-custom-cursor theme-cursor-primary"></div>
    <div class="theme-custom-cursor theme-cursor-secondary"></div>


    <div id="page" class="site">
        <a class="skip-link screen-reader-text"
            href="#content"><?php esc_html_e('Skip to the content', 'videocast'); ?></a>

        <header id="site-header" class="theme-site-header" role="banner">
            <?php get_template_part('template-parts/header/header', 'content'); ?>
        </header>
        <!-- div for fix section -->




        <div id="content" class="site-content">
            <div class="theme-page-overlay"></div>
            <div class="wrapper">
                <div class="wrapper-inner">
                    <aside class="theme-aside theme-aside-left">
                        <div class="theme-aside-content">
                            <div class="theme-filter theme-filter-category">
                                <h2 class="entry-title entry-title-small entry-title-sign" n>
                                    <?php echo esc_html__('Filter By category','videocast'); ?>
                                </h2>

                                <ul>
                                    <?php 
                                    $args = array(
                                        'orderby' => 'id',
                                        'hide_empty'=> 0,
                                    );
                                    $categories = get_categories($args);
                                    foreach ($categories as $cat) { ?>
                                    <li>
                                        <a href="<?php echo esc_url(get_category_link( $cat->term_id )); ?>"
                                            class='filter-link'><?php echo esc_html($cat->name); ?></a>
                                    </li>
                                    <?php } ?>
                                </ul>

                                <div class="filter-toggle-button">
                                    <a href=''> <?php echo esc_html__('Show More +','videocast'); ?> </a>
                                </div>
                            </div>

                            <div class="theme-filter theme-filter-tag">
                                <h2 class="entry-title entry-title-small entry-title-sign">
                                    <?php echo esc_html__('Filter By Tags','videocast'); ?>
                                </h2>

                                <ul>
                                    <?php 
                                    $tags = get_tags(array(
                                    'hide_empty' => false
                                    ));
                                    foreach ($tags as $tag) { ?>
                                    <li>
                                        <a
                                            href="<?php  echo esc_url(get_tag_link($tag->term_id)); ?>"><?php echo esc_html($tag->name); ?></a>
                                    </li>
                                    <?php } ?>
                                </ul>

                                <div class="filter-toggle-button">
                                    <a href=''> <?php echo esc_html__('Show More +','videocast'); ?> </a>

                                </div>
                            </div>

                            <div class="theme-filter them-filter-year">
                                <h2 class="entry-title entry-title-small entry-title-sign">
                                    <?php echo esc_html__('Filter By Year','videocast'); ?>
                                </h2>
                                <ul>
                                    <?php
                                 wp_get_archives(array('type' => 'yearly'));
                                ?>
                                </ul>
                            </div>

                            <div class="theme-filter theme-filter-author">
                                <h2 class="entry-title entry-title-small entry-title-sign">
                                    <?php echo esc_html__('Filter By Author','videocast'); ?>
                                </h2>

                                <?php 
                                $users = get_users( array( 'fields' => array( 'display_name','id' ) ) );
                                // Array of stdClass objects.
                                foreach ( $users as $user ) { ?>
                                <ul>
                                    <li>
                                        <a
                                            href="<?php echo esc_url(get_author_posts_url( $user->id )); ?>"><?php echo esc_html( $user->display_name); ?></a>
                                    </li>
                                </ul>
                                <?php } ?>
                            </div>

                            <?php do_action('videocast_copyright_content_action'); ?>
                        </div>
                    </aside>