<?php
/**
 * Custom Functions.
 *
 * @package Videocast
 */

if( !function_exists( 'videocast_fonts_url' ) ) :

    //Google Fonts URL
    function videocast_fonts_url(){

        $font_families = array(
            'Roboto:wght@100;300;400;500;700;900',
            'Source+Sans+3:wght@300;400;500;600',
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);

    }

endif;


if (!function_exists('videocast_iframe_escape')) :

    /** Escape Iframe **/
    function videocast_iframe_escape($input)
    {

        $all_tags = array(
            'iframe' => array(
                'width' => array(),
                'height' => array(),
                'src' => array(),
                'frameborder' => array(),
                'allow' => array(),
                'allowfullscreen' => array(),
            ),
            'video' => array(
                'width' => array(),
                'height' => array(),
                'src' => array(),
                'style' => array(),
                'controls' => array(),
            )
        );

        return wp_kses($input, $all_tags);

    }

endif;

if( !function_exists('videocast_read_more_render') ):

    function videocast_read_more_render(){ ?>
<div class="entry-meta">
    <div class="entry-meta-link">
        <a href="<?php the_permalink(); ?>">
            <?php esc_html_e('Read More','videocast'); ?>
        </a>
    </div>
</div>

<?php
    }

endif;

if( !function_exists( 'videocast_social_menu_icon' ) ) :

    function videocast_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( 'videocast-social-menu' === $args->theme_location ) {

            $svg = Videocast_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = videocast_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'videocast_social_menu_icon', 10, 4 );

if( !function_exists( 'videocast_add_sub_toggles_to_main_menu' ) ) :

    function videocast_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

        // Add sub menu toggles to the Expanded Menu with toggles.
        if( isset( $args->show_toggles ) && $args->show_toggles ){

            // Wrap the menu item link contents in a div, used for positioning.
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children.
            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle.
                $args->after .= '<button class="toggle submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'videocast' ) . '</span>' . videocast_the_theme_svg( 'chevron-down',$return = true ) . '</span></button>';

            }

            // Close the wrapper.
            $args->after .= '</div><!-- .submenu-wrapper -->';

            // Add sub menu icons to the primary menu without toggles.
        }elseif( 'videocast-primary-menu' === $args->theme_location ){

            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $args->after = '<span class="icon">'.videocast_the_theme_svg('chevron-down',true).'</span>';

            }else{

                $args->after = '';

            }
        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'videocast_add_sub_toggles_to_main_menu', 10, 3 );


/**
 * Videocast SVG Icon helper functions
 *
 * @package Videocast
 * @since 1.0.0
 */
if ( ! function_exists( 'videocast_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Videocast_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function videocast_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return videocast_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in videocast_get_theme_svg();.

        }else{

            echo videocast_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in videocast_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'videocast_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function videocast_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Videocast_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                    ' preserveAspectRatio' => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


                                
if( !function_exists( 'videocast_vertical_header_section' ) ) :

    function videocast_vertical_header_section(){
        $videocast_default = videocast_get_default_theme_options();

            $header_banner_title = get_theme_mod( 'header_banner_title',$videocast_default['header_banner_title'] );
            $header_banner_description = get_theme_mod( 'header_banner_description',$videocast_default['header_banner_description'] );
            $header_banner_signature_image = get_theme_mod( 'header_banner_signature_image');
            ?>
<article>
    <div class="entry-wrapper">
        <div class="post-content">
            <header class="entry-header">
                <h3 class="entry-title entry-title-big">
                    <?php echo esc_html($header_banner_title);?>
                </h3>
            </header>

            <div class="entry-excerpt">
                <?php echo esc_html($header_banner_description); ?>
            </div>
            <?php if (!empty($header_banner_signature_image)) { ?>
            <img src="<?php echo esc_url($header_banner_signature_image);?>">

            <?php } ?>
        </div>
    </div>
</article>
<?php
    }

endif;

if( !function_exists( 'videocast_post_category_list' ) ) :

    // Post Category List.
    function videocast_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','videocast' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('videocast_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function videocast_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('videocast_disable_post_views') ):

    /** Disable Post Views **/
    function videocast_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('videocast_disable_post_read_time') ):

    /** Disable Read Time **/
    function videocast_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('videocast_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function videocast_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('videocast_disable_post_author_box') ):

    /** Disable Author Box **/
    function videocast_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed', function ( ) {
            return false;
        });

    }

endif;


add_filter('booster_extension_filter_ss_ed', function ( ) {
    return false;
});

if( !function_exists('videocast_disable_post_reaction') ):

    /** Disable Reaction **/
    function videocast_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', function ( ) {
            return false;
        });

    }

endif;

if ( ! function_exists( 'videocast_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function videocast_header_toggle_search() {

        $videocast_default = videocast_get_default_theme_options();
        $ed_header_search = get_theme_mod( 'ed_header_search', $videocast_default['ed_header_search'] );        
        if( $ed_header_search ){ ?>

<div class="header-searchbar">
    <div class="header-searchbar-inner">
        <div class="wrapper">

            <div class="header-searchbar-area">

                <a href="javascript:void(0)" class="skip-link-search-start"></a>

                <?php get_search_form(); ?>

            </div>

            <button type="button" id="search-closer" class="exit-search">
                <?php videocast_the_theme_svg('cross'); ?>
            </button>

            <a href="javascript:void(0)" class="skip-link-search-end"></a>

        </div>
    </div>
</div>

<?php
        }

    }

endif;

add_action( 'videocast_before_footer_content_action','videocast_header_toggle_search',10 );

if( !function_exists('videocast_content_offcanvas') ):

    // Offcanvas Contents
    function videocast_content_offcanvas(){ ?>

<div id="offcanvas-menu">
    <div class="offcanvas-wraper">

        <div class="close-offcanvas-menu">
            <div class="offcanvas-close">

                <a href="javascript:void(0)" class="skip-link-menu-start"></a>

                <button type="button" class="button-offcanvas-close">
                    <?php videocast_the_theme_svg('close'); ?>
                </button>

            </div>
        </div>

        <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
            <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'videocast'); ?>"
                role="navigation">
                <ul class="primary-menu">

                    <?php
                            if( has_nav_menu('videocast-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'videocast-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{
                                
                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => false,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Videocast_Walker_Page(),
                                    )
                                );
                            } ?>

                </ul>
            </nav><!-- .primary-menu-wrapper -->
        </div>

        <?php if( has_nav_menu('videocast-social-menu') ){ ?>

        <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">

            <?php
                        wp_nav_menu(array(
                            'theme_location' => 'videocast-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>

        </div>

        <?php } ?>

        <?php do_action('videocast_copyright_content_action'); ?>

        <a href="javascript:void(0)" class="skip-link-menu-end"></a>

    </div>
</div>

<?php
    }

endif;

add_action( 'videocast_before_footer_content_action','videocast_content_offcanvas',30 );

if( !function_exists('videocast_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function videocast_footer_content_info(){

        $videocast_default = videocast_get_default_theme_options(); ?>
<div class="footer-credits">

    <div class="footer-copyright">

        <?php
                $ed_footer_copyright = wp_kses_post(get_theme_mod('ed_footer_copyright', $videocast_default['ed_footer_copyright']));
                $footer_copyright_text = wp_kses_post(get_theme_mod('footer_copyright_text', $videocast_default['footer_copyright_text']));

                echo esc_html__('Copyright ', 'videocast') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" >' . esc_html(get_bloginfo('name', 'display')) . '.</a> ' . esc_html($footer_copyright_text);

                if ($ed_footer_copyright) {

                    echo '<br>';
                    echo esc_html__('Theme: ', 'videocast') . 'Videocast ' . esc_html__('By ', 'videocast') . '<a href="' . esc_url('https://www.themeinwp.com/theme/videocast') . '"  title="' . esc_attr__('Themeinwp', 'videocast') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'videocast') . '</span></a>';

                    echo esc_html__('Powered by ', 'videocast') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'videocast') . '" target="_blank"><span>' . esc_html__('WordPress.', 'videocast') . '</span></a>';

                } ?>

    </div>


    <!-- <div class="column column-2 ">
            <?php //videocast_footer_go_to_top(); ?>
        </div> -->

</div>
<?php
    }

endif;

add_action( 'videocast_copyright_content_action','videocast_footer_content_info',20 );


if( !function_exists('videocast_footer_go_to_top') ):

    // Scroll to Top render content
    function videocast_footer_go_to_top(){ ?>

<a class="to-the-top theme-action-control" href="#site-header">
    <span class="action-control-trigger" tabindex="-1">
        <span class="to-the-top-long">
            <?php printf(esc_html__('To the top %s', 'videocast'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
        </span>
        <span class="to-the-top-short">
            <?php printf(esc_html__('Up %s', 'videocast'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
        </span>
    </span>
</a>

<?php
    }

endif;

if( ! function_exists( 'videocast_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function videocast_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','videocast_after_content_pagination');

}

if( !function_exists('videocast_after_content_pagination') ):

    function videocast_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'videocast' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('videocast_excerpt_content') ):

    function videocast_excerpt_content(){ 

        $videocast_default = videocast_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$videocast_default['ed_post_excerpt'] );

        if( $ed_post_excerpt ){ ?>

<div class="entry-content entry-content-small">

    <?php
                if( has_excerpt() ){

                    the_excerpt();

                }else{

                    echo esc_html( wp_trim_words( get_the_content(), 25, '...' ) );

                } ?>

</div>

<?php }
    }

endif;


if ( ! function_exists( 'videocast_svg_escape' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function videocast_svg_escape( $input ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            $input,
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if ( ! $svg ) {
            return false;
        }

        return $svg;

    }

endif;

if ( ! function_exists( 'videocast_comment_details' ) ):
    function videocast_comment_details($comment, $args, $depth) {
        if ( 'div' === $args['style'] ) {
            $tag       = 'div';
            $add_below = 'comment';
        } else {
            $tag       = 'li';
            $add_below = 'div-comment';
        }?>
        <<?php echo $tag; ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID() ?>"><?php 
        if ( 'div' != $args['style'] ) { ?>
            <div id="div-comment-<?php comment_ID() ?>" class="comment-body"><?php
        } ?>
            <div class="comment-author vcard"><?php 
                if ( $args['avatar_size'] != 0 ) {
                    echo get_avatar( $comment, $args['avatar_size'] ); 
                } 
                printf( esc_html__( '<cite class="fn">%s</cite> <span class="says">says:</span>' ,'videocast'), get_comment_author_link() ); ?>
                <?php 
                if ( $comment->comment_approved == '0' ) { ?>
                    <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.','videocast' ); ?></em><br/><?php 
                } ?>
                <div class="comment-meta commentmetadata">
                    <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>"><?php
                        /* translators: 1: date, 2: time */
                        printf( 
                            esc_html__('%1$s at %2$s','videocast' ), 
                            get_comment_date(),  
                            get_comment_time() 
                        ); ?>
                    </a><?php 
                    edit_comment_link( esc_html__( '(Edit)','videocast' ), '  ', '' ); ?>
                </div>
            </div>
     
            <?php comment_text(); ?>
     
            <div class="reply"><?php 
                    comment_reply_link( 
                        array_merge( 
                            $args, 
                            array( 
                                'add_below' => $add_below, 
                                'depth'     => $depth, 
                                'max_depth' => $args['max_depth'] 
                            ) 
                        ) 
                    ); ?>
            </div><?php 
        if ( 'div' != $args['style'] ) : ?>
            </div><?php 
        endif;
    }
endif;